# werkdone_excel_server
a standalone personalized excel server for the vms mcp agent, several of the tools have been derived from popular repositories such as Harris Musa and re-rewritten for the purposes of our vms mcp agent.
